@@ -12,6 +12,8 @@ generic base classes and utilities to build new solvers.
    loader
    magic
    extend_simul
+   hexa_files
+   scripts
 
 """
 from ._version import __version__
