@@ -5,8 +5,12 @@
 .. autofunction:: import_cls_simul
 
 """
+import sys
 
-import entrypoints
+if sys.version_info[:2] < (3, 10):
+    from importlib_metadata import entry_points
+else:
+    from importlib.metadata import entry_points
 
 
 def available_solvers(entrypoint_grp):
@@ -22,7 +26,7 @@ def available_solvers(entrypoint_grp):
         The name of the entrypoint group listing the solvers.
 
     """  # noqa
-    return entrypoints.get_group_named(entrypoint_grp)
+    return entry_points(group=entrypoint_grp)
 
 
 def import_module_solver(key, entrypoint_grp):
@@ -63,7 +67,7 @@ def import_cls_simul(key, entrypoint_grp):
     """
 
     if key.startswith(entrypoint_grp + "."):
-        key = key[len(entrypoint_grp) + 1:]
+        key = key[len(entrypoint_grp) + 1 :]
 
     solver = import_module_solver(key, entrypoint_grp)
     return solver.Simul
